@@ -17,40 +17,53 @@ API Reference
 import logging
 from math import isclose
 from numbers import Real
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple
 
 import numpy as np
 
-from bcdi.experiment.beamline_factory import BeamlineGoniometer, BeamlineSaxs
+from bcdi.experiment.beamline_factory import Beamline, BeamlineGoniometer, BeamlineSaxs
 from bcdi.utils import utilities as util
 from bcdi.utils import validation as valid
 
+if TYPE_CHECKING:
+    from bcdi.experiment.setup import Setup
+
 module_logger = logging.getLogger(__name__)
 
 
-def create_beamline(name, **kwargs):
+def create_beamline(name, sample_offsets=None, **kwargs) -> Beamline:
     """
     Create the instance of the beamline.
 
     :param name: str, name of the beamline
-    :param kwargs: optional beamline-dependent parameters
+    :param sample_offsets: list or tuple of angles in degrees, corresponding to
+     the offsets of each of the sample circles (the offset for the most outer circle
+     should be at index 0). The number of circles is beamline dependent. Convention:
+     the sample offsets will be subtracted to measurement the motor values.
+    :param kwargs:
+     - optional beamline-dependent parameters
+     - 'logger': an optional logger
+
     :return: the corresponding beamline instance
     """
     if name in {"ID01", "ID01BLISS"}:
-        return BeamlineID01(name=name, **kwargs)
+        return BeamlineID01(name=name, sample_offsets=sample_offsets, **kwargs)
+    if name == "BM02":
+        return BeamlineBM02(name=name, sample_offsets=sample_offsets, **kwargs)
     if name == "ID27":
-        return BeamlineID27(name=name, **kwargs)
+        return BeamlineID27(name=name, sample_offsets=sample_offsets, **kwargs)
     if name in {"SIXS_2018", "SIXS_2019"}:
-        return BeamlineSIXS(name=name, **kwargs)
+        return BeamlineSIXS(name=name, sample_offsets=sample_offsets, **kwargs)
     if name == "34ID":
-        return Beamline34ID(name=name, **kwargs)
+        return Beamline34ID(name=name, sample_offsets=sample_offsets, **kwargs)
     if name == "P10":
-        return BeamlineP10(name=name, **kwargs)
+        return BeamlineP10(name=name, sample_offsets=sample_offsets, **kwargs)
     if name == "P10_SAXS":
-        return BeamlineP10SAXS(name=name, **kwargs)
+        return BeamlineP10SAXS(name=name, sample_offsets=sample_offsets, **kwargs)
     if name == "CRISTAL":
-        return BeamlineCRISTAL(name=name, **kwargs)
+        return BeamlineCRISTAL(name=name, sample_offsets=sample_offsets, **kwargs)
     if name == "NANOMAX":
-        return BeamlineNANOMAX(name=name, **kwargs)
+        return BeamlineNANOMAX(name=name, sample_offsets=sample_offsets, **kwargs)
     raise ValueError(f"Beamline {name} not supported")
 
 
@@ -691,6 +704,277 @@ class BeamlineID01(BeamlineGoniometer):
         return mymatrix, q_offset
 
 
+class BeamlineBM02(BeamlineGoniometer):
+    """
+    Definition of ESRF BM02 beamline.
+
+    :param name: name of the beamline
+    """
+
+    def __init__(self, name: str, **kwargs) -> None:
+        super().__init__(name=name, **kwargs)
+
+    @property
+    def detector_hor(self) -> str:
+        """
+        Horizontal detector orientation expressed in the laboratory frame.
+
+        We look at the detector from upstream, detector X is along the inboard
+        direction. The laboratory frame convention is (z downstream, y vertical,
+        x outboard).
+        """
+        return "x-"
+
+    @property
+    def detector_ver(self) -> str:
+        """
+        Vertical detector orientation expressed in the laboratory frame.
+
+        The origin is at the top, detector Y along vertical down. The laboratory frame
+        convention is (z downstream, y vertical, x outboard).
+        """
+        return "y-"
+
+    def goniometer_values(self, setup: "Setup", **kwargs) -> Tuple[Any, ...]:
+        """
+        Retrieve goniometer motor positions for a BCDI rocking scan.
+
+        :param setup: the experimental setup: Class Setup
+        :param kwargs:
+         - 'scan_number': the scan number to load
+
+        :return: a tuple of angular values in degrees (rocking angular step, grazing
+         incidence angles, inplane detector angle, outofplane detector angle). The
+         grazing incidence angles are the positions of circles below the rocking circle.
+        """
+        # load kwargs
+        scan_number = kwargs["scan_number"]
+
+        # check some parameter
+        valid.valid_item(
+            scan_number, allowed_types=int, min_excluded=0, name="scan_number"
+        )
+
+        # load motor positions
+        (
+            mu,
+            th,
+            chi,
+            phi,
+            inplane_angle,
+            outofplane_angle,
+            energy,
+            detector_distance,
+        ) = self.loader.motor_positions(
+            setup=setup,
+            scan_number=scan_number,
+        )
+
+        grazing: Optional[Tuple[Real, ...]] = None
+
+        # define the circles of interest in BCDI
+        if setup.rocking_angle == "outofplane":  # th rocking curve
+            grazing = (mu,)
+            tilt_angle = th
+        elif setup.rocking_angle == "inplane":  # phi rocking curve
+            grazing = (mu, th, chi)
+            tilt_angle = phi
+        else:  # energy scan
+            tilt_angle = energy
+
+        setup.check_setup(
+            grazing_angle=grazing,
+            inplane_angle=inplane_angle,
+            outofplane_angle=outofplane_angle,
+            tilt_angle=tilt_angle,
+            detector_distance=detector_distance,
+            energy=energy,
+        )
+
+        # BM02 goniometer, 4S+2D (sample: mu, th, chi, phi / detector: nu, tth)
+        self.sample_angles = (mu, th, chi, phi)
+        self.detector_angles = (inplane_angle, outofplane_angle)
+
+        return tilt_angle, grazing, inplane_angle, outofplane_angle
+
+    def process_positions(
+        self,
+        setup: "Setup",
+        nb_frames: int,
+        scan_number: int,
+        frames_logical: Optional[np.ndarray] = None,
+    ) -> List[Any]:
+        """
+        Load and crop/pad motor positions depending on the number of frames at BM02.
+
+        The current number of frames may be different from the original number of frames
+        if the data was cropped/padded, and motor values must be processed accordingly.
+
+        :param setup: an instance of the class Setup
+        :param nb_frames: the number of frames in the current dataset
+        :param scan_number: the scan number to load
+        :param frames_logical: array of length the number of measured frames.
+         In case of cropping/padding the number of frames changes. A frame whose
+         index is set to 1 means that it is used, 0 means not used, -1 means padded
+         (added) frame
+        :return: a tuple of 1D arrays (sample circles, detector circles, energy)
+        """
+        mu, th, chi, phi, nu, tth, energy, _ = super().process_positions(
+            setup=setup,
+            nb_frames=nb_frames,
+            scan_number=scan_number,
+            frames_logical=frames_logical,
+        )
+
+        # eventually crop/pad motor values if the provided dataset was further
+        # cropped/padded
+        if setup.rocking_angle == "outofplane":  # th rocking curve
+            nb_steps = len(th)
+            tilt_angle = (th[1:] - th[0:-1]).mean()
+            th = self.process_tilt(
+                th, nb_steps=nb_steps, nb_frames=nb_frames, step_size=tilt_angle
+            )
+        elif setup.rocking_angle == "inplane":  # phi rocking curve
+            nb_steps = len(phi)
+            tilt_angle = (phi[1:] - phi[0:-1]).mean()
+            phi = self.process_tilt(
+                phi, nb_steps=nb_steps, nb_frames=nb_frames, step_size=tilt_angle
+            )
+        elif setup.rocking_angle == "energy":
+            nb_steps = len(energy)
+            tilt_angle = (energy[1:] - energy[0:-1]).mean()
+            energy = self.process_tilt(
+                energy, nb_steps=nb_steps, nb_frames=nb_frames, step_size=tilt_angle
+            )
+        else:
+            raise ValueError('Wrong value for "rocking_angle" parameter')
+
+        return util.bin_parameters(
+            binning=setup.detector.binning[0],
+            nb_frames=nb_frames,
+            params=[mu, th, chi, phi, nu, tth, energy],
+        )
+
+    def transformation_matrix(
+        self,
+        wavelength,
+        distance,
+        pixel_x,
+        pixel_y,
+        inplane,
+        outofplane,
+        grazing_angle,
+        tilt,
+        rocking_angle,
+        verbose=True,
+    ):
+        """
+        Calculate the transformation matrix from detector frame to laboratory frame.
+
+        For the transformation in direct space, the length scale is in nm,
+        for the transformation in reciprocal space, it is in 1/nm.
+
+        :param wavelength: X-ray wavelength in nm
+        :param distance: detector distance in nm
+        :param pixel_x: horizontal detector pixel size in nm
+        :param pixel_y: vertical detector pixel size in nm
+        :param inplane: horizontal detector angle in radians
+        :param outofplane: vertical detector angle in radians
+        :param grazing_angle: angle or list of angles of the sample circles which are
+         below the rotated circle
+        :param tilt: angular step of the rocking curve in radians
+        :param rocking_angle: "outofplane", "inplane" or "energy"
+        :param verbose: True to have printed comments
+        :return: a tuple of two numpy arrays
+
+         - the transformation matrix from the detector frame to the
+           laboratory frame in reciprocal space (reciprocal length scale in  1/nm), as a
+           numpy array of shape (3,3)
+         - the q offset (3D vector)
+
+        """
+        lambdaz = wavelength * distance
+        mymatrix = np.zeros((3, 3))
+        q_offset = np.zeros(3)
+
+        if verbose:
+            self.logger.info("using BM02 geometry")
+
+        if isinstance(grazing_angle, Real):
+            grazing_angle = (grazing_angle,)
+        valid.valid_container(
+            grazing_angle,
+            container_types=(tuple, list),
+            item_types=Real,
+            min_length=1,
+            name="grazing_angle",
+        )
+
+        if rocking_angle == "outofplane":
+            if verbose:
+                self.logger.info(
+                    f"rocking angle is th, mu={grazing_angle[0] * 180 / np.pi:.3f} deg"
+                )
+            # rocking omega angle clockwise around x at mu=0,
+            # chi potentially non zero (chi below omega)
+            # (phi does not matter, above eta)
+            mymatrix[:, 0] = (
+                2
+                * np.pi
+                / lambdaz
+                * pixel_x
+                * self.orientation_lookup[self.detector_hor]
+                * np.array([-np.cos(inplane), 0, np.sin(inplane)])
+            )
+            mymatrix[:, 1] = (
+                2
+                * np.pi
+                / lambdaz
+                * pixel_y
+                * self.orientation_lookup[self.detector_ver]
+                * np.array(
+                    [
+                        np.sin(inplane) * np.sin(outofplane),
+                        -np.cos(outofplane),
+                        np.cos(inplane) * np.sin(outofplane),
+                    ]
+                )
+            )
+            mymatrix[:, 2] = (
+                2
+                * np.pi
+                / lambdaz
+                * tilt
+                * distance
+                * np.array(
+                    [
+                        np.sin(grazing_angle[0]) * np.sin(outofplane),
+                        np.cos(grazing_angle[0])
+                        * (1 - np.cos(inplane) * np.cos(outofplane))
+                        - np.sin(grazing_angle[0])
+                        * np.cos(outofplane)
+                        * np.sin(inplane),
+                        np.sin(outofplane) * np.cos(grazing_angle[0]),
+                    ]
+                )
+            )
+            q_offset[0] = (
+                2 * np.pi / lambdaz * distance * np.cos(outofplane) * np.sin(inplane)
+            )
+            q_offset[1] = 2 * np.pi / lambdaz * distance * np.sin(outofplane)
+            q_offset[2] = (
+                2
+                * np.pi
+                / lambdaz
+                * distance
+                * (np.cos(inplane) * np.cos(outofplane) - 1)
+            )
+        else:
+            raise NotImplementedError(f"rocking_angle={rocking_angle} not implemented")
+
+        return mymatrix, q_offset
+
+
 class BeamlineNANOMAX(BeamlineGoniometer):
     """
     Definition of MAX IV NANOMAX beamline.
@@ -1274,7 +1558,7 @@ class BeamlineP10(BeamlineGoniometer):
                 )
 
             # rocking phi angle clockwise around y,
-            # omega and chi potentially non zero (chi below omega below phi)
+            # omega and chi potentially non zero (om below chi below phi)
             mymatrix[:, 0] = (
                 2
                 * np.pi
