@@ -10,6 +10,7 @@
 
 """Postprocessing of the output from the facet analyzer plugin for Paraview."""
 
+import logging
 import pathlib
 from typing import Any, Dict, List, Optional, Tuple, Union, no_type_check
 
@@ -22,9 +23,11 @@ import vtk
 from ipywidgets import Layout, interactive
 from pandas import DataFrame
 
-from bcdi.utils import utilities as util
+import bcdi.utils.format as ft
 from bcdi.utils import validation as valid
 
+module_logger = logging.getLogger(__name__)
+
 
 class Facets:
     """
@@ -61,6 +64,7 @@ class Facets:
         pathdir: str = "./",
         savedir: Optional[str] = None,
         lattice: float = 3.912,
+        **kwargs,
     ) -> None:
         # Create other required parameters with default None value
         self.nb_facets: Optional[int] = None
@@ -82,7 +86,7 @@ class Facets:
         self.planar_dist = None
         self.ref_normal = None
         self.theoretical_angles: Optional[Dict[str, float]] = None
-
+        self.logger = kwargs.get("logger", module_logger)
         # Check input parameters
         valid.valid_container(
             pathdir, container_types=str, min_length=1, name="pathdir"
@@ -207,26 +211,58 @@ class Facets:
         # Get point data
         try:
             point_data = vtkdata.GetPointData()
-            print("Loading data...")
+            self.logger.info("Loading data...")
         except AttributeError:
             raise NameError("This file does not exist or is not right.")
 
-        print(f"Number of points = {vtkdata.GetNumberOfPoints()}")
-        print(f"Number of cells = {vtkdata.GetNumberOfCells()}")
+        self.logger.info(f"Number of points = {vtkdata.GetNumberOfPoints()}")
+        self.logger.info(f"Number of cells = {vtkdata.GetNumberOfCells()}")
 
-        self.vtk_data = {
-            "x": [vtkdata.GetPoint(i)[0] for i in range(vtkdata.GetNumberOfPoints())],
-            "y": [vtkdata.GetPoint(i)[1] for i in range(vtkdata.GetNumberOfPoints())],
-            "z": [vtkdata.GetPoint(i)[2] for i in range(vtkdata.GetNumberOfPoints())],
-            "strain": [
-                point_data.GetArray("strain").GetValue(i)
-                for i in range(vtkdata.GetNumberOfPoints())
-            ],
-            "disp": [
-                point_data.GetArray("disp").GetValue(i)
-                for i in range(vtkdata.GetNumberOfPoints())
-            ],
-        }
+        try:
+            self.vtk_data = {
+                "x": [
+                    vtkdata.GetPoint(i)[0] for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "y": [
+                    vtkdata.GetPoint(i)[1] for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "z": [
+                    vtkdata.GetPoint(i)[2] for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "strain": [
+                    point_data.GetArray("strain").GetValue(i)
+                    for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "disp": [
+                    point_data.GetArray("disp").GetValue(i)
+                    for i in range(vtkdata.GetNumberOfPoints())
+                ],
+            }
+
+            self.phase_or_disp = "disp"
+
+        except AttributeError:
+            self.vtk_data = {
+                "x": [
+                    vtkdata.GetPoint(i)[0] for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "y": [
+                    vtkdata.GetPoint(i)[1] for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "z": [
+                    vtkdata.GetPoint(i)[2] for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "strain": [
+                    point_data.GetArray("strain").GetValue(i)
+                    for i in range(vtkdata.GetNumberOfPoints())
+                ],
+                "phase": [
+                    point_data.GetArray("phase").GetValue(i)
+                    for i in range(vtkdata.GetNumberOfPoints())
+                ],
+            }
+
+            self.phase_or_disp = "phase"
 
         # Get cell data
         cell_data = vtkdata.GetCellData()
@@ -250,7 +286,7 @@ class Facets:
         ]
 
         self.nb_facets = int(max(self.vtk_data["facet_id"]))
-        print(f"Number of facets = {self.nb_facets}")
+        self.logger.info(f"Number of facets = {self.nb_facets}")
 
         # Get means
         facet_indices = np.arange(1, int(self.nb_facets) + 1, 1)
@@ -262,13 +298,13 @@ class Facets:
         disp_std = np.zeros(self.nb_facets)  # stored later in field data
 
         for ind in facet_indices:
-            print(f"Facet = {ind}")
+            self.logger.info(f"Facet = {ind}")
             results = self.extract_facet(int(ind), plot=False)
             if results is not None:
                 strain_mean[ind - 1] = results["strain_mean"]
                 strain_std[ind - 1] = results["strain_std"]
-                disp_mean[ind - 1] = results["disp_mean"]
-                disp_std[ind - 1] = results["disp_std"]
+                disp_mean[ind - 1] = results[self.phase_or_disp + "_mean"]
+                disp_std[ind - 1] = results[self.phase_or_disp + "_std"]
 
         # Get field data
         field_data = vtkdata.GetFieldData()
@@ -278,8 +314,8 @@ class Facets:
         ]
         self.field_data["strain_mean"] = strain_mean
         self.field_data["strain_std"] = strain_std
-        self.field_data["disp_mean"] = disp_mean
-        self.field_data["disp_std"] = disp_std
+        self.field_data[self.phase_or_disp + "_mean"] = disp_mean
+        self.field_data[self.phase_or_disp + "_std"] = disp_std
         self.field_data["n0"] = [
             field_data.GetArray("facetNormals").GetValue(3 * i)
             for i in range(self.nb_facets)
@@ -335,7 +371,6 @@ class Facets:
         self,
         u0: np.ndarray,
         v0: np.ndarray,
-        w0: np.ndarray,
         u: np.ndarray,
         v: np.ndarray,
     ) -> None:
@@ -348,18 +383,18 @@ class Facets:
 
         :param u0: numpy.ndarray, shape (3,)
         :param v0: numpy.ndarray, shape (3,)
-        :param w0: numpy.ndarray, shape (3,)
         :param u: numpy.ndarray, shape (3,)
         :param v: numpy.ndarray, shape (3,)
         """
         # Check parameters
-        valid.valid_ndarray(arrays=(u0, v0, w0, u, v), shape=(3,))
+        valid.valid_ndarray(arrays=(u0, v0, u, v), shape=(3,))
 
         # Input theoretical values for three facets' normals
-        self.u0 = u0
-        self.v0 = v0
-        self.w0 = w0
-        print("Cross product of u0 and v0:", np.cross(self.u0, self.v0))
+        w0 = np.cross(u0, v0)
+        self.u0 = u0 / np.linalg.norm(u0)
+        self.v0 = v0 / np.linalg.norm(v0)
+        self.w0 = w0 / np.linalg.norm(w0)
+        self.logger.info(f"Cross product of u0 and v0: {w0}")
 
         # Current values for the first two facets' normals,
         # to compute the rotation matrix
@@ -369,7 +404,7 @@ class Facets:
         self.norm_u = self.u / np.linalg.norm(self.u)
         self.norm_v = self.v / np.linalg.norm(self.v)
         self.norm_w = np.cross(self.norm_u, self.norm_v)
-        print("Normalized cross product of u and v:", self.norm_w)
+        self.logger.info(f"Normalized cross product of u and v: {self.norm_w}")
 
         # Transformation matrix
         tensor0 = np.array([self.u0, self.v0, self.w0])
@@ -393,9 +428,11 @@ class Facets:
 
         try:
             for e in normals.keys():
-                normals[e] = np.dot(self.rotation_matrix, normals[e])
+                normals[e] = np.dot(
+                    self.rotation_matrix, normals[e] / np.linalg.norm(normals[e])
+                )
         except AttributeError:
-            print(
+            self.logger.info(
                 """You need to define the rotation matrix first if you want to rotate
                 the particle. Please choose vectors from the normals in field data"""
             )
@@ -546,7 +583,7 @@ class Facets:
             plt.show()
 
     @no_type_check
-    def test_vector(self, vec: np.ndarray) -> None:
+    def test_rotation_matrix(self, vec: np.ndarray) -> None:
         """
         Computes value of a vector passed through the rotation matrix.
 
@@ -557,11 +594,13 @@ class Facets:
         valid.valid_ndarray(vec, shape=(3,), name="vec")
 
         try:
-            print(np.dot(self.rotation_matrix, vec / np.linalg.norm(vec)))
+            self.logger.info(
+                f"{np.dot(self.rotation_matrix, vec / np.linalg.norm(vec))}"
+            )
         except AttributeError:
-            print("You need to define the rotation matrix before")
+            self.logger.info("You need to define the rotation matrix before")
         except TypeError:
-            print("You need to define the rotation matrix before")
+            self.logger.info("You need to define the rotation matrix before")
 
     def extract_facet(
         self,
@@ -611,7 +650,7 @@ class Facets:
             "y": np.zeros(len(voxel_indices_new)),
             "z": np.zeros(len(voxel_indices_new)),
             "strain": np.zeros(len(voxel_indices_new)),
-            "disp": np.zeros(len(voxel_indices_new)),
+            self.phase_or_disp: np.zeros(len(voxel_indices_new)),
         }
 
         for j, _ in enumerate(voxel_indices_new):
@@ -619,11 +658,13 @@ class Facets:
             results["y"][j] = self.vtk_data["y"][int(voxel_indices_new[j])]
             results["z"][j] = self.vtk_data["z"][int(voxel_indices_new[j])]
             results["strain"][j] = self.vtk_data["strain"][int(voxel_indices_new[j])]
-            results["disp"][j] = self.vtk_data["disp"][int(voxel_indices_new[j])]
+            results[self.phase_or_disp][j] = self.vtk_data[self.phase_or_disp][
+                int(voxel_indices_new[j])
+            ]
         results["strain_mean"] = np.mean(results["strain"])
         results["strain_std"] = np.std(results["strain"])
-        results["disp_mean"] = np.mean(results["disp"])
-        results["disp_std"] = np.std(results["disp"])
+        results[self.phase_or_disp + "_mean"] = np.mean(results[self.phase_or_disp])
+        results[self.phase_or_disp + "_std"] = np.std(results[self.phase_or_disp])
 
         # plot single result
         if plot:
@@ -671,7 +712,7 @@ class Facets:
                 n1 = row.n1.values[0]
                 n2 = row.n2.values[0]
                 n = np.array([n0, n1, n2])
-                print(f"Facet normal: {np.round(n, 2)}")
+                self.logger.info(f"Facet normal: {np.round(n, 2)}")
             except IndexError:
                 pass  # we are on the corners and edges
             except Exception as e:
@@ -998,7 +1039,14 @@ class Facets:
 
         # 3D displacement
         p = None
-        fig_name = "disp_3D_" + self.hkls + self.comment + "_" + str(self.disp_range)
+        fig_name = (
+            self.phase_or_disp
+            + "_3D_"
+            + self.hkls
+            + self.comment
+            + "_"
+            + str(self.disp_range)
+        )
         fig = plt.figure(figsize=figsize)
         ax = fig.add_subplot(projection="3d")
 
@@ -1010,7 +1058,7 @@ class Facets:
                     results["y"],
                     results["z"],
                     s=50,
-                    c=results["disp"],
+                    c=results[self.phase_or_disp],
                     cmap=self.cmap,
                     vmin=-self.disp_range,
                     vmax=self.disp_range,
@@ -1020,7 +1068,7 @@ class Facets:
 
         fig.colorbar(p)
         ax.view_init(elev=elev, azim=azim)
-        plt.title("Displacement for each voxel", fontsize=self.title_fontsize)
+        plt.title(f"{self.phase_or_disp} for each voxel", fontsize=self.title_fontsize)
         ax.tick_params(axis="both", which="major", labelsize=self.ticks_fontsize)
         ax.tick_params(axis="both", which="minor", labelsize=self.ticks_fontsize)
 
@@ -1030,7 +1078,12 @@ class Facets:
 
         # Average disp
         fig_name = (
-            "disp_3D_avg_" + self.hkls + self.comment + "_" + str(self.disp_range_avg)
+            self.phase_or_disp
+            + "_3D_avg_"
+            + self.hkls
+            + self.comment
+            + "_"
+            + str(self.disp_range_avg)
         )
         fig = plt.figure(figsize=figsize)
         ax = fig.add_subplot(projection="3d")
@@ -1038,8 +1091,8 @@ class Facets:
         for ind in range(1, self.nb_facets):
             results = self.extract_facet(ind, plot=False)
             if results is not None:
-                disp_mean_facet = np.zeros(results["disp"].shape)
-                disp_mean_facet.fill(results["disp_mean"])
+                disp_mean_facet = np.zeros(results[self.phase_or_disp].shape)
+                disp_mean_facet.fill(results[self.phase_or_disp + "_mean"])
                 self.disp_mean_facets = np.append(
                     self.disp_mean_facets, disp_mean_facet, axis=0
                 )
@@ -1059,7 +1112,7 @@ class Facets:
 
         fig.colorbar(p)
         ax.view_init(elev=elev, azim=azim)
-        plt.title("Mean displacement per facet", fontsize=self.title_fontsize)
+        plt.title(f"Mean {self.phase_or_disp} per facet", fontsize=self.title_fontsize)
         ax.tick_params(axis="both", which="major", labelsize=self.ticks_fontsize)
         ax.tick_params(axis="both", which="minor", labelsize=self.ticks_fontsize)
 
@@ -1103,17 +1156,19 @@ class Facets:
         for _, row in self.field_data.iterrows():
             ax.errorbar(
                 row["facet_id"],
-                row["disp_mean"],
-                row["disp_std"],
+                row[self.phase_or_disp + "_mean"],
+                row[self.phase_or_disp + "_std"],
                 fmt="o",
                 label=row["legend"],
             )
 
         ax.set_title(
-            "Average displacement vs facet index", fontsize=self.title_fontsize
+            f"Average {self.phase_or_disp} vs facet index", fontsize=self.title_fontsize
         )
         ax.set_xlabel("Facet index", fontsize=self.axes_fontsize)
-        ax.set_ylabel("Average retrieved displacement", fontsize=self.axes_fontsize)
+        ax.set_ylabel(
+            f"Average retrieved {self.phase_or_disp}", fontsize=self.axes_fontsize
+        )
 
         ax.legend(
             bbox_to_anchor=(1, 1),
@@ -1174,9 +1229,15 @@ class Facets:
         plt.savefig(self.pathsave + fig_name + ".png", bbox_inches="tight")
         plt.show()
 
-        # disp, strain & size vs angle planes,
+        # phase or disp, strain & size vs angle planes,
+        # Remove edges and corners here
         # change line style as a fct of the planes indices
-        fig_name = "disp_strain_size_vs_angle_planes_" + self.hkls + self.comment
+        fig_name = (
+            self.phase_or_disp
+            + "_strain_size_vs_angle_planes_"
+            + self.hkls
+            + self.comment
+        )
         fig, (ax0, ax1, ax2) = plt.subplots(3, 1, sharex="all", figsize=(10, 12))
 
         plt.xticks(fontsize=self.ticks_fontsize)
@@ -1197,31 +1258,32 @@ class Facets:
         ax0.set_yticks(minor_y_ticks, minor=True)
 
         for _, row in self.field_data.iterrows():
-            try:
-                lx, ly = (
-                    float(row.legend.split()[0]),
-                    float(row.legend.split()[1]),
-                )
-                if lx >= 0:
-                    if ly >= 0:
-                        fmt = "o"
+            if row.facet_id != 0:
+                try:
+                    lx, ly = (
+                        float(row.legend.split()[0]),
+                        float(row.legend.split()[1]),
+                    )
+                    if lx >= 0:
+                        if ly >= 0:
+                            fmt = "o"
+                        else:
+                            fmt = "d"
+                    elif ly >= 0:
+                        fmt = "s"
                     else:
-                        fmt = "d"
-                elif ly >= 0:
-                    fmt = "s"
-                else:
+                        fmt = "+"
+                except AttributeError:
                     fmt = "+"
-            except AttributeError:
-                fmt = "+"
-            ax0.errorbar(
-                row["interplanar_angles"],
-                row["disp_mean"],
-                row["disp_std"],
-                fmt=fmt,
-                capsize=2,
-                label=row["legend"],
-            )
-        ax0.set_ylabel("Retrieved <disp> (A)", fontsize=self.axes_fontsize)
+                ax0.errorbar(
+                    row["interplanar_angles"],
+                    row[self.phase_or_disp + "_mean"],
+                    row[self.phase_or_disp + "_std"],
+                    fmt=fmt,
+                    capsize=2,
+                    label=row["legend"],
+                )
+        ax0.set_ylabel(f"Retrieved <{self.phase_or_disp}>", fontsize=self.axes_fontsize)
         ax0.legend(
             loc="upper left",
             bbox_to_anchor=(1, 1),
@@ -1245,30 +1307,31 @@ class Facets:
         ax1.set_yticks(minor_y_ticks, minor=True)
 
         for _, row in self.field_data.iterrows():
-            try:
-                lx, ly = (
-                    float(row.legend.split()[0]),
-                    float(row.legend.split()[1]),
-                )
-                if lx >= 0:
-                    if ly >= 0:
-                        fmt = "o"
+            if row.facet_id != 0:
+                try:
+                    lx, ly = (
+                        float(row.legend.split()[0]),
+                        float(row.legend.split()[1]),
+                    )
+                    if lx >= 0:
+                        if ly >= 0:
+                            fmt = "o"
+                        else:
+                            fmt = "d"
+                    elif ly >= 0:
+                        fmt = "s"
                     else:
-                        fmt = "d"
-                elif ly >= 0:
-                    fmt = "s"
-                else:
+                        fmt = "+"
+                except AttributeError:
                     fmt = "+"
-            except AttributeError:
-                fmt = "+"
-            ax1.errorbar(
-                row["interplanar_angles"],
-                row["strain_mean"],
-                row["strain_std"],
-                fmt=fmt,
-                capsize=2,
-                label=row["legend"],
-            )
+                ax1.errorbar(
+                    row["interplanar_angles"],
+                    row["strain_mean"],
+                    row["strain_std"],
+                    fmt=fmt,
+                    capsize=2,
+                    label=row["legend"],
+                )
         ax1.set_ylabel("Retrieved <strain>", fontsize=self.axes_fontsize)
         ax1.grid(which="minor", alpha=0.2)
         ax1.grid(which="major", alpha=0.5)
@@ -1285,12 +1348,13 @@ class Facets:
         ax2.set_yticks(minor_y_ticks, minor=True)
 
         for _, row in self.field_data.iterrows():
-            ax2.plot(
-                row["interplanar_angles"],
-                row["rel_facet_size"],
-                "o",
-                label=row["legend"],
-            )
+            if row.facet_id != 0:
+                ax2.plot(
+                    row["interplanar_angles"],
+                    row["rel_facet_size"],
+                    "o",
+                    label=row["legend"],
+                )
         ax2.set_xlabel("Angle (deg.)", fontsize=self.axes_fontsize)
         ax2.set_ylabel("Relative facet size", fontsize=self.axes_fontsize)
         ax2.grid(which="minor", alpha=0.2)
@@ -1309,8 +1373,10 @@ class Facets:
                         "facet_id": [0],
                         "strain_mean": result["strain_mean"],
                         "strain_std": result["strain_std"],
-                        "disp_mean": result["disp_mean"],
-                        "disp_std": result["disp_std"],
+                        self.phase_or_disp
+                        + "_mean": result[self.phase_or_disp + "_mean"],
+                        self.phase_or_disp
+                        + "_std": result[self.phase_or_disp + "_std"],
                         "n0": None,
                         "n1": None,
                         "n2": None,
@@ -1375,10 +1441,10 @@ class Facets:
                 facets.create_dataset("planar_dist", data=self.planar_dist)
                 facets["planar_dist"].attrs["units"] = "Angstrom"
                 facets.create_dataset("ref_normal", data=self.ref_normal)
-                print("Saved Facets class attributes")
+                self.logger.info("Saved Facets class attributes")
 
             except ValueError:
-                print("Data already exists, overwriting ...")
+                self.logger.info("Data already exists, overwriting ...")
 
                 f["/entry_1/process_4/path_to_data"][...] = self.path_to_data
                 f["/entry_1/process_4/nb_facets"][...] = self.nb_facets
@@ -1397,11 +1463,11 @@ class Facets:
                 f["/entry_1/process_4/planar_dist"][...] = self.planar_dist
                 f["/entry_1/process_4/planar_dist"].attrs["units"] = "Angstrom"
                 f["/entry_1/process_4/ref_normal"][...] = self.ref_normal
-                print("Saved Facets class attributes")
+                self.logger.info("Saved Facets class attributes")
 
             except (AttributeError, TypeError):
                 try:
-                    print(
+                    self.logger.info(
                         "Particle not rotated, some attributes could not be saved ..."
                     )
                     facets.create_dataset("u0", data=np.zeros(3))
@@ -1433,6 +1499,28 @@ class Facets:
 
         # Save field data
         try:
+            # Replace nan by zeroes for edges and corners and change dtype
+            # so that we can save as hdf
+            self.field_data.iloc[0, 5:] = np.zeros(10)
+            self.field_data = self.field_data.astype(
+                {
+                    "facet_id": "int64",
+                    "strain_mean": "float64",
+                    "strain_std": "float64",
+                    "phase_mean": "float64",
+                    "phase_std": "float64",
+                    "n0": "float64",
+                    "n1": "float64",
+                    "n2": "float64",
+                    "c0": "float64",
+                    "c1": "float64",
+                    "c2": "float64",
+                    "interplanar_angles": "float64",
+                    "abs_facet_size": "float64",
+                    "rel_facet_size": "float64",
+                    "legend": str,
+                }
+            )
             self.field_data.to_hdf(
                 path_to_data,
                 key="entry_1/process_4/tables/field_data",
@@ -1441,7 +1529,7 @@ class Facets:
                 format="table",
                 data_columns=True,
             )
-            print("Saved field data")
+            self.logger.info("Saved field data")
 
         except Exception as e:
             raise e
@@ -1464,16 +1552,16 @@ class Facets:
                 format="table",
                 data_columns=True,
             )
-            print("Saved theoretical angles")
+            self.logger.info("Saved theoretical angles")
 
         except AttributeError:
-            print("Facets has no attribute theoretical_angles yet")
+            self.logger.info("Facets has no attribute theoretical_angles yet")
         except Exception as e:
             raise e
 
     def __repr__(self):
         """Unambiguous representation of the class."""
-        return util.create_repr(obj=self, cls=Facets)
+        return ft.create_repr(obj=self, cls=Facets)
 
     def __str__(self):
         """Readable representation of the class."""
