@@ -7,41 +7,47 @@
 #         Jerome Carnis, jerome.carnis@esrf.fr
 """Functions related to forward CDI data preprocessing, before phase retrieval."""
 
+import logging
+from numbers import Real
 
 import matplotlib.pyplot as plt
-from numbers import Real
 import numpy as np
 
-from ..experiment import diffractometer as diff
-from ..graph import graph_utils as gu
-from ..utils import utilities as util
-from ..utils import validation as valid
+from bcdi.constants import BEAMLINES_SAXS
+from bcdi.graph import graph_utils as gu
+from bcdi.utils import utilities as util
+from bcdi.utils import validation as valid
+
+module_logger = logging.getLogger(__name__)
 
 
-def beamstop_correction(data, detector, setup, debugging=False):
+def beamstop_correction(data, setup, debugging=False, **kwargs):
     """
     Correct absorption from the beamstops during P10 forward CDI experiment.
 
     :param data: the 3D stack of 2D CDI images, shape = (nbz, nby, nbx) or 2D image of
      shape (nby, nbx)
-    :param detector: the detector object: Class experiment_utils.Detector()
     :param setup: an instance of the class Setup
     :param debugging: set to True to see plots
+    :param kwargs:
+     - 'logger': an optional logger
+
     :return: the corrected data
     """
+    logger = kwargs.get("logger", module_logger)
     valid.valid_ndarray(arrays=data, ndim=(2, 3))
     energy = setup.energy
     if not isinstance(energy, Real):
         raise TypeError(f"Energy should be a number in eV, not a {type(energy)}")
 
-    print(f"Applying beamstop correction for the X-ray energy of {energy}eV")
+    logger.info(f"Applying beamstop correction for the X-ray energy of {energy}eV")
 
     if energy not in [8200, 8700, 10000, 10235]:
-        print(
-            "no beam stop information for the X-ray energy of {:d}eV,"
-            " defaulting to the correction for 8700 eV".format(int(energy))
+        logger.info(
+            f"No beam stop information for the X-ray energy of {int(energy):d}eV,"
+            " skip beamstop masking"
         )
-        energy = 8700
+        return data
 
     ndim = data.ndim
     if ndim == 3:
@@ -52,8 +58,8 @@ def beamstop_correction(data, detector, setup, debugging=False):
         raise ValueError("2D or 3D data expected")
     nbz, nby, nbx = data.shape
 
-    directbeam_y = setup.direct_beam[0] - detector.roi[0]  # vertical
-    directbeam_x = setup.direct_beam[1] - detector.roi[2]  # horizontal
+    directbeam_y = setup.direct_beam[0] - setup.detector.roi[0]  # vertical
+    directbeam_x = setup.direct_beam[1] - setup.detector.roi[2]  # horizontal
 
     # at 8200eV, the transmission of 100um Si is 0.26273
     # at 8700eV, the transmission of 100um Si is 0.32478
@@ -319,7 +325,7 @@ def beamstop_correction(data, detector, setup, debugging=False):
     return data
 
 
-def check_cdi_angle(data, mask, cdi_angle, frames_logical, debugging=False):
+def check_cdi_angle(data, mask, cdi_angle, frames_logical, debugging=False, **kwargs):
     """
     Check for overlaps of the sample rotation motor position in forward CDI experiment.
 
@@ -334,13 +340,17 @@ def check_cdi_angle(data, mask, cdi_angle, frames_logical, debugging=False):
      In case of padding the length changes. A frame whose index is set to 1 means
      that it is used, 0 means not used, -1 means padded (added) frame.
     :param debugging: True to have more printed comments
+    :param kwargs:
+     - 'logger': an optional logger
+
     :return: updated data, mask, detector cdi_angle, frames_logical
     """
+    logger = kwargs.get("logger", module_logger)
     valid.valid_ndarray(arrays=(data, mask), ndim=3)
     detector_angle = np.zeros(len(cdi_angle))
     # flip the rotation axis in order to compensate the rotation of the Ewald sphere
     # due to sample rotation
-    print(
+    logger.info(
         "Reverse the rotation direction to compensate the rotation of the Ewald sphere"
     )
     for idx, item in enumerate(cdi_angle):
@@ -357,7 +367,9 @@ def check_cdi_angle(data, mask, cdi_angle, frames_logical, debugging=False):
         )  # set frames_logical to 0 if duplicated angle
 
     if debugging:
-        print("frames_logical after checking duplicated angles:\n", frames_logical)
+        logger.info(
+            f"frames_logical after checking duplicated angles: {frames_logical}"
+        )
 
     # find first duplicated angle
     try:
@@ -368,15 +380,14 @@ def check_cdi_angle(data, mask, cdi_angle, frames_logical, debugging=False):
             detector_angle[index_duplicated] = detector_angle[index_duplicated] - 0.0001
         else:
             detector_angle[index_duplicated] = detector_angle[index_duplicated] + 0.0001
-        print(
-            "RegularGridInterpolator cannot take duplicated values: shifting frame",
-            index_duplicated,
-            "by 1/10000 degrees for the interpolation",
+        logger.info(
+            "RegularGridInterpolator cannot take duplicated values: shifting frame "
+            f"{index_duplicated} by 1/10000 degrees for the interpolation",
         )
 
         frames_logical[index_duplicated] = 1
     except IndexError:  # no duplicated angle
-        print("no duplicated angle")
+        logger.info("no duplicated angle")
 
     data = data[np.nonzero(frames_logical)[0], :, :]
     mask = mask[np.nonzero(frames_logical)[0], :, :]
@@ -387,7 +398,6 @@ def check_cdi_angle(data, mask, cdi_angle, frames_logical, debugging=False):
 def grid_cdi(
     data,
     mask,
-    detector,
     setup,
     frames_logical,
     correct_curvature=False,
@@ -403,9 +413,6 @@ def grid_cdi(
 
     :param data: the 3D data, already binned in the detector frame
     :param mask: the corresponding 3D mask
-    :param detector: an instance of the class Detector.
-     The detector orientation is supposed to follow the CXI convention: (z
-     downstream, y vertical up, x outboard) Y opposite to y, X opposite to x
     :param setup: an instance of the class Setup
     :param frames_logical: array of initial length the number of measured frames.
      In case of padding the length changes. A frame whose index is set to 1 means
@@ -417,25 +424,36 @@ def grid_cdi(
      - 'fill_value': tuple of two real numbers, fill values to use for pixels outside
        of the interpolation range. The first value is for the data, the second for the
        mask. Default is (0, 0)
+     - 'logger': an optional logger
 
     :return: the data and mask interpolated in the laboratory frame, q values
      (downstream, vertical up, outboard)
     """
+    logger = kwargs.get("logger", module_logger)
     fill_value = kwargs.get("fill_value", (0, 0))
     valid.valid_ndarray(arrays=(data, mask), ndim=3)
-    if setup.beamline == "P10_SAXS":
-        if setup.rocking_angle == "inplane":
-            if setup.custom_scan:
+    if setup.rocking_angle == "inplane":
+        if setup.custom_scan:
+            # TODO: create a list of stage names per beamline  # skipcq: PYL-W0511
+            # to avoid having to harcode it here
+            if setup.name == "P10_SAXS":
                 cdi_angle = setup.custom_motors["hprz"]
+            elif setup.name == "ID27":
+                cdi_angle = setup.custom_motors["nath"]
             else:
-                cdi_angle, _, _ = setup.diffractometer.motor_positions(setup=setup)
-                # second return value is the X-ray energy, third the detector distance
+                raise NotImplementedError(
+                    f"Not yet implemented for beamlines other than {BEAMLINES_SAXS}"
+                )
         else:
-            raise ValueError(
-                "out-of-plane rotation not yet implemented for forward CDI data"
-            )
+            cdi_angle, _, _, _, _, _ = setup.loader.motor_positions(setup=setup)
+
     else:
-        raise NotImplementedError("Not yet implemented for beamlines other than P10")
+        raise ValueError(
+            "out-of-plane rotation not yet implemented for forward CDI data"
+        )
+
+    if len(setup.diffractometer.sample_circles) != 1:
+        raise NotImplementedError("Grazing angle not supported for this geometry.")
 
     data, mask, cdi_angle, frames_logical = check_cdi_angle(
         data=data,
@@ -445,19 +463,17 @@ def grid_cdi(
         debugging=debugging,
     )
     if debugging:
-        print("\ncdi_angle", cdi_angle)
-    nbz, nby, nbx = data.shape
-    print("\nData shape after check_cdi_angle and before regridding:", nbz, nby, nbx)
-    print("\nAngle range:", cdi_angle.min(), cdi_angle.max())
+        logger.info(f"cdi_angle {cdi_angle}")
+    logger.info(f"Data shape after check_cdi_angle and before regridding: {data.shape}")
+    logger.info(f"Angle range: {cdi_angle.min():.3f}deg - {cdi_angle.max():.3f}deg")
 
-    (interp_data, interp_mask), q_values, corrected_dirbeam = setup.ortho_cdi(
+    (interp_data, interp_mask), q_values, offseted_direct_beam = setup.ortho_cdi(
         arrays=(data, mask),
         cdi_angle=cdi_angle,
         fill_value=fill_value,
         correct_curvature=correct_curvature,
         debugging=debugging,
     )
-    qx, qz, qy = q_values
 
     # check for Nan
     interp_mask[np.isnan(interp_data)] = 1
@@ -471,23 +487,25 @@ def grid_cdi(
     interp_data[np.nonzero(interp_mask)] = 0
 
     # calculate the position in pixels of the origin of the reciprocal space
-    pivot_z = int((setup.direct_beam[1] - detector.roi[2]) / detector.binning[2])
+    pivot_z = int(
+        (setup.direct_beam[1] - setup.detector.roi[2]) / setup.detector.binning[2]
+    )
     # 90 degrees conter-clockwise rotation of detector X around qz, downstream
     _, numy, numx = interp_data.shape
-    pivot_y = int(numy - corrected_dirbeam[0])
+    pivot_y = int(numy - offseted_direct_beam[0])
     # detector Y vertical down, opposite to qz vertical up
-    pivot_x = int(numx - corrected_dirbeam[1])
+    pivot_x = int(numx - offseted_direct_beam[1])
     # detector X inboard at P10, opposite to qy outboard
-    print(
-        "\nOrigin of the reciprocal space (Qx,Qz,Qy): "
-        f"({pivot_z}, {pivot_y}, {pivot_x})\n"
+    logger.info(
+        "Origin of the reciprocal space (Qx,Qz,Qy): "
+        f"({pivot_z}, {pivot_y}, {pivot_x})"
     )
 
     # plot the gridded data
     final_binning = (
-        detector.preprocessing_binning[2] * detector.binning[2],
-        detector.preprocessing_binning[1] * detector.binning[1],
-        detector.preprocessing_binning[2] * detector.binning[2],
+        setup.detector.preprocessing_binning[2] * setup.detector.binning[2],
+        setup.detector.preprocessing_binning[1] * setup.detector.binning[1],
+        setup.detector.preprocessing_binning[2] * setup.detector.binning[2],
     )
     plot_comment = (
         f"_{numx}_{numy}_{numx}"
@@ -499,7 +517,7 @@ def grid_cdi(
     max_z = interp_data.sum(axis=0).max()
     fig, _, _ = gu.contour_slices(
         interp_data,
-        (qx, qz, qy),
+        q_values,
         sum_frames=True,
         title="Regridded data",
         levels=np.linspace(0, np.ceil(np.log10(max_z)), 150, endpoint=True),
@@ -515,12 +533,12 @@ def grid_cdi(
         + "     ({:d}, {:d}, {:d})".format(pivot_z, pivot_y, pivot_x),
         size=14,
     )
-    fig.savefig(detector.savedir + "reciprocal_space_sum" + plot_comment)
+    fig.savefig(setup.detector.savedir + "reciprocal_space_sum" + plot_comment)
     plt.close(fig)
 
     fig, _, _ = gu.contour_slices(
         interp_data,
-        (qx, qz, qy),
+        q_values,
         sum_frames=False,
         title="Regridded data",
         levels=np.linspace(
@@ -539,7 +557,7 @@ def grid_cdi(
         + "     ({:d}, {:d}, {:d})".format(pivot_z, pivot_y, pivot_x),
         size=14,
     )
-    fig.savefig(detector.savedir + "reciprocal_space_central" + plot_comment)
+    fig.savefig(setup.detector.savedir + "reciprocal_space_central" + plot_comment)
     plt.close(fig)
 
     fig, _, _ = gu.multislices_plot(
@@ -560,7 +578,7 @@ def grid_cdi(
         + "     ({:d}, {:d}, {:d})".format(pivot_z, pivot_y, pivot_x),
         size=14,
     )
-    fig.savefig(detector.savedir + "reciprocal_space_central_pix" + plot_comment)
+    fig.savefig(setup.detector.savedir + "reciprocal_space_central_pix" + plot_comment)
     plt.close(fig)
     if debugging:
         gu.multislices_plot(
@@ -574,13 +592,13 @@ def grid_cdi(
             reciprocal_space=True,
         )
 
-    return interp_data, interp_mask, [qx, qz, qy], frames_logical
+    return interp_data, interp_mask, list(q_values), frames_logical
 
 
 def load_cdi_data(
     scan_number,
-    detector,
     setup,
+    mask_beamstop: bool = False,
     bin_during_loading=False,
     flatfield=None,
     hotpixels=None,
@@ -596,8 +614,9 @@ def load_cdi_data(
     and binning.
 
     :param scan_number: the scan number to load
-    :param detector: an instance of the class Detector
     :param setup: an instance of the class Setup
+    :param mask_beamstop: True to apply beamstop correction (direct beam on the
+     detector, masked by a beam stop)
     :param bin_during_loading: True to bin the data during loading (faster)
     :param flatfield: the 2D flatfield array
     :param hotpixels: the 2D hotpixels array. 1 for a hotpixel, 0 for normal pixels.
@@ -611,6 +630,7 @@ def load_cdi_data(
      - 'frames_pattern': 1D array of int, of length data.shape[0]. If
        frames_pattern is 0 at index, the frame at data[index] will be skipped,
        if 1 the frame will added to the stack.
+     - 'logger': an optional logger
 
     :return:
      - the 3D data and mask arrays
@@ -620,6 +640,7 @@ def load_cdi_data(
      - the monitor values used for the intensity normalization
 
     """
+    logger = kwargs.get("logger", module_logger)
     valid.valid_item(bin_during_loading, allowed_types=bool, name="bin_during_loading")
     # check and load kwargs
     valid.valid_kwargs(
@@ -639,9 +660,8 @@ def load_cdi_data(
         frames_pattern, allow_none=True, allowed_values={0, 1}, name="frames_pattern"
     )
 
-    rawdata, rawmask, monitor, frames_logical = setup.diffractometer.load_check_dataset(
+    rawdata, rawmask, monitor, frames_logical = setup.loader.load_check_dataset(
         scan_number=scan_number,
-        detector=detector,
         setup=setup,
         frames_pattern=frames_pattern,
         bin_during_loading=bin_during_loading,
@@ -655,9 +675,8 @@ def load_cdi_data(
     #################################
     # apply the beamstop correction #
     #################################
-    rawdata = beamstop_correction(
-        data=rawdata, detector=detector, setup=setup, debugging=debugging
-    )
+    if mask_beamstop:
+        rawdata = beamstop_correction(data=rawdata, setup=setup, debugging=debugging)
 
     #####################################################
     # apply an optional photon threshold before binning #
@@ -665,26 +684,28 @@ def load_cdi_data(
     if photon_threshold != 0:
         rawmask[rawdata < photon_threshold] = 1
         rawdata[rawdata < photon_threshold] = 0
-        print("Applying photon threshold before binning: < ", photon_threshold)
+        logger.info(f"Applying photon threshold before binning: < {photon_threshold}")
 
     ####################################################################################
     # bin data and mask in the detector plane if not already done during loading       #
     # binning in the stacking dimension is done at the very end of the data processing #
     ####################################################################################
     if not bin_during_loading and (
-        (detector.binning[1] != 1) or (detector.binning[2] != 1)
+        (setup.detector.binning[1] != 1) or (setup.detector.binning[2] != 1)
     ):
-        print(
-            "Binning the data: detector vertical axis by",
-            detector.binning[1],
-            ", detector horizontal axis by",
-            detector.binning[2],
+        logger.info(
+            f"Binning the data: detector vertical axis by {setup.detector.binning[1]}, "
+            f"detector horizontal axis by {setup.detector.binning[2]}"
         )
         rawdata = util.bin_data(
-            rawdata, (1, detector.binning[1], detector.binning[2]), debugging=False
+            rawdata,
+            (1, setup.detector.binning[1], setup.detector.binning[2]),
+            debugging=False,
         )
         rawmask = util.bin_data(
-            rawmask, (1, detector.binning[1], detector.binning[2]), debugging=False
+            rawmask,
+            (1, setup.detector.binning[1], setup.detector.binning[2]),
+            debugging=False,
         )
         rawmask[np.nonzero(rawmask)] = 1
 
@@ -693,9 +714,10 @@ def load_cdi_data(
     ################################################
     rawdata, rawmask = util.pad_from_roi(
         arrays=(rawdata, rawmask),
-        roi=detector.roi,
-        binning=detector.binning[1:],
+        roi=setup.detector.roi,
+        binning=setup.detector.binning[1:],
         pad_value=(0, 1),
+        logger=logger,
     )
 
     return rawdata, rawmask, frames_logical, monitor
@@ -705,7 +727,6 @@ def reload_cdi_data(
     data,
     mask,
     scan_number,
-    detector,
     setup,
     normalize_method="skip",
     debugging=False,
@@ -717,20 +738,21 @@ def reload_cdi_data(
     :param data: the 3D data array
     :param mask: the 3D mask array
     :param scan_number: the scan number to load
-    :param detector: an instance of the class Detector
     :param setup: an instance of the class Setup
     :param normalize_method: 'skip' to skip, 'monitor'  to normalize by the default
      monitor, 'sum_roi' to normalize by the integrated intensity in a defined region
      of interest
     :param debugging:  set to True to see plots
-    :parama kwargs:
+    :param kwargs:
      - 'photon_threshold' = float, photon threshold to apply before binning
+     - 'logger': an optional logger
 
     :return:
      - the updated 3D data and mask arrays
      - the monitor values used for the intensity normalization
 
     """
+    logger = kwargs.get("logger", module_logger)
     valid.valid_ndarray(arrays=(data, mask), ndim=3)
     # check and load kwargs
     valid.valid_kwargs(
@@ -749,52 +771,56 @@ def reload_cdi_data(
     nbz, nby, nbx = data.shape
     frames_logical = np.ones(nbz)
 
-    print(
-        (data < 0).sum(), " negative data points masked"
-    )  # can happen when subtracting a background
+    logger.info(f"{(data < 0).sum()} negative data points masked")
+    # can happen when subtracting a background
     mask[data < 0] = 1
     data[data < 0] = 0
 
     # normalize by the incident X-ray beam intensity
     if normalize_method == "skip":
-        print("Skip intensity normalization")
+        logger.info("Skip intensity normalization")
         monitor = []
     else:
         if normalize_method == "sum_roi":
             monitor = data[
                 :,
-                detector.sum_roi[0] : detector.sum_roi[1],
-                detector.sum_roi[2] : detector.sum_roi[3],
+                setup.detector.sum_roi[0] : setup.detector.sum_roi[1],
+                setup.detector.sum_roi[2] : setup.detector.sum_roi[3],
             ].sum(axis=(1, 2))
         else:  # use the default monitor of the beamline
-            monitor = setup.diffractometer.read_monitor(
+            monitor = setup.loader.read_monitor(
                 scan_number=scan_number,
                 setup=setup,
             )
 
-        print("Intensity normalization using " + normalize_method)
-        data, monitor = diff.normalize_dataset(
+        logger.info(f"Intensity normalization using {normalize_method}")
+        data, monitor = setup.loader.normalize_dataset(
             array=data,
             monitor=monitor,
             norm_to_min=True,
-            savedir=detector.savedir,
+            savedir=setup.detector.savedir,
             debugging=True,
+            logger=logger,
         )
 
     # pad the data to the shape defined by the ROI
     if (
-        detector.roi[1] - detector.roi[0] > nby
-        or detector.roi[3] - detector.roi[2] > nbx
+        setup.detector.roi[1] - setup.detector.roi[0] > nby
+        or setup.detector.roi[3] - setup.detector.roi[2] > nbx
     ):
-        start = (0, max(0, abs(detector.roi[0])), max(0, abs(detector.roi[2])))
-        print("Paddind the data to the shape defined by the ROI")
+        start = (
+            0,
+            max(0, abs(setup.detector.roi[0])),
+            max(0, abs(setup.detector.roi[2])),
+        )
+        logger.info("Paddind the data to the shape defined by the ROI")
         data = util.crop_pad(
             array=data,
             pad_start=start,
             output_shape=(
                 data.shape[0],
-                detector.roi[1] - detector.roi[0],
-                detector.roi[3] - detector.roi[2],
+                setup.detector.roi[1] - setup.detector.roi[0],
+                setup.detector.roi[3] - setup.detector.roi[2],
             ),
         )
         mask = util.crop_pad(
@@ -803,8 +829,8 @@ def reload_cdi_data(
             pad_start=start,
             output_shape=(
                 mask.shape[0],
-                detector.roi[1] - detector.roi[0],
-                detector.roi[3] - detector.roi[2],
+                setup.detector.roi[1] - setup.detector.roi[0],
+                setup.detector.roi[3] - setup.detector.roi[2],
             ),
         )
 
@@ -812,22 +838,24 @@ def reload_cdi_data(
     if photon_threshold != 0:
         mask[data < photon_threshold] = 1
         data[data < photon_threshold] = 0
-        print("Applying photon threshold before binning: < ", photon_threshold)
+        logger.info(f"Applying photon threshold before binning: < {photon_threshold}")
 
     # bin data and mask in the detector plane if needed
     # binning in the stacking dimension is done at the very end of the data processing
-    if (detector.binning[1] != 1) or (detector.binning[2] != 1):
-        print(
-            "Binning the data: detector vertical axis by",
-            detector.binning[1],
-            ", detector horizontal axis by",
-            detector.binning[2],
+    if (setup.detector.binning[1] != 1) or (setup.detector.binning[2] != 1):
+        logger.info(
+            f"Binning the data: detector vertical axis by {setup.detector.binning[1]}, "
+            f"detector horizontal axis by {setup.detector.binning[2]}"
         )
         data = util.bin_data(
-            data, (1, detector.binning[1], detector.binning[2]), debugging=debugging
+            data,
+            (1, setup.detector.binning[1], setup.detector.binning[2]),
+            debugging=debugging,
         )
         mask = util.bin_data(
-            mask, (1, detector.binning[1], detector.binning[2]), debugging=debugging
+            mask,
+            (1, setup.detector.binning[1], setup.detector.binning[2]),
+            debugging=debugging,
         )
         mask[np.nonzero(mask)] = 1
 
