@@ -7,18 +7,20 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-from matplotlib import pyplot as plt
-import matplotlib.ticker as ticker
-from numbers import Real
-import numpy as np
 import pathlib
-from scipy.ndimage.measurements import center_of_mass
 import tkinter as tk
+from numbers import Real
 from tkinter import filedialog
 
+import matplotlib.ticker as ticker
+import numpy as np
+from matplotlib import pyplot as plt
+from scipy.ndimage.measurements import center_of_mass
+
 import bcdi.graph.graph_utils as gu
 import bcdi.utils.utilities as util
 import bcdi.utils.validation as valid
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Template for figures of the following article:
@@ -106,8 +108,7 @@ if grey_background:
     bad_color = "0.7"
 else:
     bad_color = "1.0"  # white background
-colormap = gu.Colormap(bad_color=bad_color)
-my_cmap = colormap.cmap
+my_cmap = ColormapFactory(bad_color=bad_color).cmap
 
 #########################
 # check some parameters #
