@@ -7,22 +7,24 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-import numpy as np
-from numpy.random import poisson
-from numpy.fft import fftn, fftshift
-from matplotlib import pyplot as plt
-import tkinter as tk
-from tkinter import filedialog
-from scipy.interpolate import RegularGridInterpolator
 import gc
 import os
 import sys
+import tkinter as tk
+from tkinter import filedialog
+
+import numpy as np
+from matplotlib import pyplot as plt
+from numpy.fft import fftn, fftshift
+from numpy.random import poisson
+from scipy.interpolate import RegularGridInterpolator
+
 import bcdi.graph.graph_utils as gu
-from bcdi.experiment.detector import create_detector
-from bcdi.experiment.setup import Setup
 import bcdi.postprocessing.postprocessing_utils as pu
 import bcdi.simulation.simulation_utils as simu
 import bcdi.utils.utilities as util
+from bcdi.experiment.setup import Setup
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Using a support created from a reconstructed object (real space), calculate the
@@ -117,16 +119,13 @@ comment = ""  # should start with _
 # define colormap #
 ###################
 bad_color = "1.0"  # white background
-colormap = gu.Colormap(bad_color=bad_color)
-my_cmap = colormap.cmap
+my_cmap = ColormapFactory(bad_color=bad_color).cmap
 
 ################
 # define setup #
 ################
-detector = create_detector(name=detector)
 setup = Setup(
-    beamline=beamline,
-    detector=detector,
+    beamline_name=beamline,
     energy=energy,
     outofplane_angle=outofplane_angle,
     inplane_angle=inplane_angle,
@@ -134,6 +133,7 @@ setup = Setup(
     rocking_angle=rocking_angle,
     grazing_angle=grazing_angle,
     distance=original_sdd,
+    detector_name=detector,
 )
 
 #########################
@@ -229,7 +229,7 @@ phase = util.wrap(phase, start_angle=-np.pi, range_angle=2 * np.pi)
 support[abs(amp) < support_threshold * abs(amp).max()] = 0
 del amp
 
-volume = support.sum() * voxel_size ** 3  # in nm3
+volume = support.sum() * voxel_size**3  # in nm3
 print("estimated volume", volume, " nm3")
 
 phase[support == 0] = 0
@@ -471,12 +471,14 @@ print("Multiplication factor for the real-space voxel size:  pad_size/original_s
 
 # compensate change in detector distance
 comment = comment + "_sdd_" + str("{:.2f}".format(simulated_sdd))
-print("\nCurrent detector pixel size", detector.unbinned_pixel_size[0] * 1e6, "um")
+print(
+    "\nCurrent detector pixel size", setup.detector.unbinned_pixel_size[0] * 1e6, "um"
+)
 print(
     "Detector pixel size to compensate the change in detector distance",
     str(
         "{:.2f}".format(
-            detector.unbinned_pixel_size[0] * 1e6 * original_sdd / simulated_sdd
+            setup.detector.unbinned_pixel_size[0] * 1e6 * original_sdd / simulated_sdd
         )
     ),
     "um",
