@@ -7,21 +7,24 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-import time
-import warnings
 import datetime
-import numpy as np
-from matplotlib import pyplot as plt
-from scipy.interpolate import RegularGridInterpolator
-import tkinter as tk
-from tkinter import filedialog
 import gc
 import multiprocessing as mp
 import sys
+import time
+import tkinter as tk
+import warnings
+from tkinter import filedialog
+
+import numpy as np
+from matplotlib import pyplot as plt
+from scipy.interpolate import RegularGridInterpolator
+
 import bcdi.graph.graph_utils as gu
+import bcdi.postprocessing.facet_recognition as fu
 import bcdi.utils.utilities as util
 import bcdi.xcca.xcca_utils as xcca
-import bcdi.postprocessing.facet_recognition as fu
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Calculate the angular cross-correlation in a 3D reciprocal space dataset over a range
@@ -114,7 +117,7 @@ def main(calc_self, user_comment):
         raise ValueError("at least 2 values are needed for q_range")
 
     print("the CCF map will be calculated for {:d} q values: ".format(len(q_range)))
-    for idx, item in enumerate(q_range):
+    for _, item in enumerate(q_range):
         if calc_self:
             print(f"q1 = {item:.3f}  q2 = {item:.3f}")
         else:
@@ -125,8 +128,7 @@ def main(calc_self, user_comment):
     # define colormap #
     ###################
     bad_color = "1.0"  # white background
-    colormap = gu.Colormap(bad_color=bad_color)
-    my_cmap = colormap.cmap
+    my_cmap = ColormapFactory(bad_color=bad_color).cmap
     plt.ion()
 
     ###################################
