@@ -7,20 +7,23 @@
 #       authors:
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
-import time
-import warnings
 import datetime
-import numpy as np
-from matplotlib import pyplot as plt
-import tkinter as tk
-from tkinter import filedialog
 import gc
 import multiprocessing as mp
 import sys
+import time
+import tkinter as tk
+import warnings
+from tkinter import filedialog
+
+import numpy as np
+from matplotlib import pyplot as plt
+
 import bcdi.graph.graph_utils as gu
+import bcdi.postprocessing.facet_recognition as fu
 import bcdi.utils.utilities as util
 import bcdi.xcca.xcca_utils as xcca
-import bcdi.postprocessing.facet_recognition as fu
+from bcdi.graph.colormap import ColormapFactory
 
 helptext = """
 Calculate the angular cross-correlation in a 3D reciprocal space dataset at the same
@@ -138,8 +141,7 @@ def main(user_comment):
     # define colormap #
     ###################
     bad_color = "1.0"  # white background
-    colormap = gu.Colormap(bad_color=bad_color)
-    my_cmap = colormap.cmap
+    my_cmap = ColormapFactory(bad_color=bad_color).cmap
     plt.ion()
 
     ###################################
