@@ -8,14 +8,42 @@
 
 import unittest
 from numbers import Integral, Real
+
 import numpy as np
+
 import bcdi.utils.validation as valid
+from tests.config import run_tests
 
 
-def run_tests(test_class):
-    suite = unittest.TestLoader().loadTestsFromTestCase(test_class)
-    runner = unittest.TextTestRunner(verbosity=2)
-    return runner.run(suite)
+class TestIsFloat(unittest.TestCase):
+    """
+    Tests on the function utilities.is_float.
+
+    def is_float(string)
+    """
+
+    def test_string_float(self):
+        self.assertTrue(valid.is_float("12.0"))
+
+    def test_string_int(self):
+        self.assertTrue(valid.is_float("12"))
+
+    def test_string_complex(self):
+        self.assertFalse(valid.is_float("12 + 1j"))
+
+    def test_string_none(self):
+        self.assertFalse(valid.is_float("None"))
+
+    def test_string_not_numeric(self):
+        self.assertFalse(valid.is_float("abc"))
+
+    def test_none(self):
+        with self.assertRaises(TypeError):
+            valid.is_float(None)
+
+    def test_array(self):
+        with self.assertRaises(TypeError):
+            valid.is_float(np.ones(3))
 
 
 class TestValidContainer(unittest.TestCase):
@@ -817,6 +845,7 @@ class TestValidNdArray(unittest.TestCase):
 
 
 if __name__ == "__main__":
+    run_tests(TestIsFloat)
     run_tests(TestValidContainer)
     run_tests(TestValidKwargs)
     run_tests(TestValidItem)
